*234567890123456789012345678901234567890123456789012345678901234567890123456789012345678

	program PLOTDUSTY

c     Martin Groenewegen  20 July 2009
c
c     Plot SED and spectra. 
c     Use format of input and filenames from MyDusty code
c
c     Subroutine readphot and readspec have to be in sync with version used in MyDusty.f
c     Subroutine getphot has to be in sync with PSCfoldORIG in MyDusty.f

C     09.08.09 Initially, PLOTLIMTS WERE HARDCODED, SEARCH FOR 'change'.
c              Created file Plotlimits.dat to read in all this.
c     04.11.09 Debugged with bound-check !! 

c     12.08.10 Added info to spec_*.dat to indicate regions not used in the fit.
c     23.08.10 -Check on normalisation range (cmin-cmax) and range spectra
c              -spectra normalised to 1.e-12 W/m2

c     03.09.10 converted to DOUBLE PRECISION
c     03.09.10 Caught cases with negative fluxes in observed spectrum
c     16.09.10 Ymax SED also set by observed photometry (not only model and spectra)
c     28.09.10 Ymax spectra limited by values within wavelength range plotted
c     20.10.10 .. and Ymin as well, and considering minimum of model+observations
c     02.11.10 Added VISTA filters
c     05.11.10 caught case when there are no observed spectra
c     11.06.11 in readspec do no check on excluded regions ! Plot all!
c     13.12.11 the then version to _v2.
c              plot linesigment for *ALL* excluded regions in the spectra             
c     30.01.12 allow monochromatic fluxdensities to be plotted
c     28 Feb 2012 Added some COBE + VISIR filters
c     27.05.12 the then version to _v3.
c              correct and update filters and ZPs
c     23.07.12 added the code to plot the name of the atmosphere model 
c              (default is NOT, look for 'xt=' near line 610, and uncomment call pgtext one line lower)
c     27.11.12 increased length of atmosname
c     31.05.13 atmosname. previously ony correct for C-star models. Correct this + make 'xt' real
c     13.08.13 jj=0 kk=0 initialised w.r.t. atmosname
c     05.02.13 in getphot replaces 'xsel' by 'isel' for 116,117,118 

c     Version 4
c     19.09.14 Calculate luminosity by integrating under SED 
c     10.10.14 Add  GALEX, MACHO and CN/TiO filters
c     10.10.14 updated to npL=515
c     05/12/14 Added EROS filters; from no=129 to 139
c     06/12/14 Allow plotting of dust file name, look for 'xt=' near line 610, and uncomment call pgtext one line lower
c              (near line 130 and 140 decide between plotting atmosphere name of dust species name)
c     20/12/14 Added Cousins RI filters
c     26/01/15 'plotname' to 40 characters
c     17/02                  45 chars, re-position
c     16/03                  50 chars, re-position, dust + atmosname
c     02/04    ZP in ISOCAM LW10 was off by factor 100.
c     09/05                  60 chars, re-position, dust + atmosname
c

c     Version 5
c     25.03.16 From no=129 to 169; added 30 JWST filters.
c     20.04.16 added COBE-DIRBE filters 1 and 2 (as 163, 164)
c     10.05.16 Added ACS and WFC3 filters; no=189
c     14.07.16  Added Gaia filters
c     20.07.16  Revision of Vega model, check filters, update ZPs
c     21.07.16  npL=573
c     18.08.17  feature: moved 'call pgwindow' lower, so that the 
c                 check on ymax from photometry is actually used.

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

cc     f77 -fbounds-check -O -o PlotMyDusty.exe PlotMyDusty.f -lpgplot -lpng

c     gfortran -fbounds-check -O -o PlotMyDusty.exe PlotMyDusty_v5.f -lpgplot 

c    PlotMyDusty.exe cwleo_in   

c =====================================================================================================================

        implicit double precision(a-h,o-z)

        parameter (npL=573, no=189, ns= 1900)

        double precision wve(npl+1),flx(npl+1),ysel(no),zsel(no)
        double precision xspec(ns),yspec(ns),zspec(ns)
        integer xsel(no),nfl,nsel,nspec
        real  specmin(4), specmax(4), exmin(10),exmax(10),dyn
	double precision irsscale, irserrscale

	character*80 rtinname,starname,name,path
	character*35 cdum
	character*90 dustname
	character*120 atmosname
	character*60 plotname, plotname1

	common/pltlim/wvemin,wvemax,dyn,specmin,specmax,cmin,cmax,npspec
	common/fnames/starname,wavecut,plotname,plotname1
        common/observations/wve,flx,ysel,zsel,xspec,yspec,zspec,xsel,
     c                      nfl,nsel,nspec,dist
	common /global/ irsscale,irserrscale,exmin,exmax, nexl

c ======================================================================================

c     open file that contains parameters to drive the plot
	open(10, file= 'Plotlimits.dat')
c       4 header lines
	do i=1,4
	  read(10,*) name
	enddo
c       SED is plotted between these wavelengths
	read(10,*) wvemin, wvemax
c       Y-Range for SED is between ymax-DYN,ymax+0.5 (in log units)
	read(10,*) dyn
c       Number of plotwindows with spectra
	read(10,*) npspec
c       for each, read min and max wavelength
	do i= 1,npspec
	   read(10,*) specmin(i), specmax(i)
	enddo
c       model and spectral observations are scaled to each other based on the 
c       average flux in this wavelenght interval
	read(10,*) cmin, cmax
	close(10)

c ======================================================================================

c     read filename with all inputs
	call getarg (1, rtinname)

c     open it and read in parameters/data, etc
	open(10, file= rtinname)

c     root name of object. Most in- and out-put files are based on this root-name
	read(10,'(a80)') starname
	read(10,*) dummy
	read(10,'(a90)') dustname
	read(10,'(a120)') atmosname
	read(10,*) Teff
	read(10,*) dist
        close(10)

c       atmosphere name
	jj=0
	kk=0
c       look for '/'
	do i= 1,119
	   if (atmosname(i:i)   .eq. '/')   jj=i
	   if (atmosname(i:i+1) .eq. 'ty')  kk=i
	enddo
	write(*,*) jj,kk
	if (atmosname(jj+1:jj+5) .eq. 'mxcom') then
c        C-model atmosphere
	   plotname=atmosname(jj+10:kk-10)
	else
c        M-model atmosphere
	   plotname=atmosname(jj+2:kk-46)
c        PHOENIX
	   if (jj+2 .gt. kk-46) plotname=atmosname(jj+1:kk-16)
	endif

c       dust species name
	jj=0
	kk=0
c       look for '/'
	do i= 1,89
	   if (dustname(i:i)   .eq. '/')   jj=i
	   if (dustname(i:i+1) .eq. 'at')  kk=i
	enddo
	write(*,*) jj,kk
	plotname1= dustname(jj+1:kk-3)

	open(10, file= 'wavecut')
        read(10,*) wavecut
	if (wavecut .le. 0.d0) wavecut= 0.001d0
	write(*,*) 'wavecut ' , wavecut,'|',plotname,'|'
        close(10)

c       for debugging
        CALL Clean(starname, path, lpath)                                      
        CALL ATTACH(path,lpath,'_debugplot.dat',name)

	open(80,file= name)

c       read in observed magnitudes and error (subroutine from MyDusty)
c       xsel contains the index to that magnitude in the model
	call readphot(xsel,ysel,zsel,nsel)
	do i= 1,nsel
   	   write(80,*)'pht', i, nsel,xsel(i),ysel(i),zsel(i)
c   	   write(*,*)'pht', i, nsel,xsel(i),ysel(i),zsel(i)
	enddo

c	read in observed spectra (subroutine from MyDusty)
	call readspec(xspec,yspec,zspec,nspec)
	do i= 1,nspec
     	  write(80,*)'spc',i,nspec,xspec(i),yspec(i),zspec(i)
	enddo

c     read in model flux
        CALL Clean(starname, path, lpath)                                  
        CALL ATTACH(path,lpath,'.dat',name)
        CALL Clean(name, path, lpath)                                          
        CALL ATTACHfront(path,lpath,'rted_',name)
        open(21, file= name)
        write(*,*) 'read model ', name, nsel

        i=0
 100    i=i+1
c     flux in W/m2
  	read(21,*, err=101,end=101) wve(i), flx(i)
c     W/m2/mu
        flx(i)= flx(i)/wve(i)
        write(80,*) 'model ', i,wve(i), flx(i)
        goto 100
 101    continue
        close(21)
        nfl= i-1

c     read in spec*.dat
        CALL Clean(starname, path, lpath)                                       
        CALL ATTACH(path,lpath,'.dat',name)
        CALL Clean(name, path, lpath)                                          
        CALL ATTACHfront(path,lpath,'spec_',name)
        open(31, file= name)
        write(*,*) 'read spec info ', name

	nexl= 0
	read(31,*) idum
	do i=1,idum
	   read(31, '(a35)') cdum
	   read(31,*) idum, irsscale, irserrscale
	   read(31,*) nex
	   do j= 1,nex
	      nexl= nexl+1
	      read(31,*) exmin(nexl),exmax(nexl)
	      write(*,*) 'EXCL', i,j,nexl, exmin(nexl),exmax(nexl)
	   end do
	enddo

	close(31)

        call plotsed

        close(80)

        stop
        end
*23456789012345678901234567890123456789012345678901234567890123456789012

      SUBROUTINE Attach(root,length,ext,fname)                                  
c     Attaches extensions to the root cleaned by Clean                          
c =======================================================================       
      CHARACTER*(*) root, ext, fname                                            
      INTEGER i, length                                                         
c -----------------------------------------------------------------------       
      DO i = 1, LEN(fname)                                                      
        fname(i:i) = ' '                                                        
      END DO                                                                    
      fname(:length) = root(:length)                                            
      fname(length + 1:) = ext                                                  
c -----------------------------------------------------------------------       
      RETURN                                                                    
      END                                                                       
c ***********************************************************************       

      SUBROUTINE AttachFront(root,length,ext,fname)                            
c     Adds a string in front of the root cleaned by Clean              
c =======================================================================       
      CHARACTER*(*) root, ext, fname                                            
      INTEGER i, length                                                         
c -----------------------------------------------------------------------       
      DO i = 1, LEN(fname)                                                      
        fname(i:i) = ' '                                                        
      END DO                                                                    
      fname(:LEN(ext)) = ext
      fname(LEN(ext)+1:LEN(ext)+1+length) = root(:length)

      RETURN                                                                    
      END                                                                       
c ***********************************************************************       
                                                                                
      SUBROUTINE Clean(StrIn, StrOut, Length)                                   
c =======================================================================       
c     Find meaningful part of StrIn without leading and trailing junk           
c     It is returned left-justified in StrOut, right-padded with blanks         
c     The number of meaningful characters is returned in Length.                
c     In case of any problems, StrOut is empty. This sub should be used to      
c     clean every input filename immediately after DUSTY reads it. [ME,'99]     
c =======================================================================       
      CHARACTER*(*) StrIn, StrOut                                               
      INTEGER i, first, last, Length                                            
c -----------------------------------------------------------------------       
      DO i = 1, LEN(StrOut)                                                     
        StrOut(i:i) = ' '                                                       
      END DO                                                                    
      first = 1                                                                 
      last = LEN(StrIn)                                                         
      If (first.gt.last) return                                                 
c     Find end of leading junk:                                                 
      DO WHILE (StrIn(first:first).LE.' ')                                      
       first = first + 1                                                        
       if (first.gt.last) return                                                
      END DO                                                                    
c     Find start of trailing junk:                                              
      DO WHILE (StrIn(last:last).LE.' ')                                        
       last = last - 1                                                          
       if (last.lt.first) return                                                
      END DO                                                                    
c     Now trim all junk:                                                        
      StrOut = StrIn(first:last)                                                
      Length = last - first + 1                                                 
c -----------------------------------------------------------------------       
      RETURN                                                                    
      END                                                                       
c ***********************************************************************       
                                                                               
*23456789012345678901234567890123456789012345678901234567890123456789012

        subroutine plotsed

c     plot SED + spectra

        implicit double precision(a-h,o-z)
	parameter(npL=573, no=189, ns= 1900)

        double precision wve(npL+1), flx(npL+1),ysel(no),zsel(no)
        real xpl(ns), ypl(ns), zpl(ns), xpl1(ns), ypl1(ns), ypl2(ns)
        real vpl(ns), wpl(ns)

        double precision xspec(ns),yspec(ns),zspec(ns),zpl1(ns),zpl2(ns)

        real specmin(4), specmax(4), xt, xt1, Lum
	real exmin(10),exmax(10)
	double precision irsscale, irserrscale

	integer symbol(ns), xsel(no), idx(ns), nsel,nfl,nspec, idx1(ns)
	
	real xmin, xmax, ymin, ymax, dyn, wl, ff, er, xx(2), yy(2)
	real vsminx,vsmaxx,vsminy,vsmaxy
	real vsminxi,vsmaxxi,vsminyi,vsmaxyi,x1,x2,y1,y2
        double precision splam(no),spmag(no),sperrmag(no)

	character*80 starname,name,path
	character*60 plotname, plotname1

	common/pltlim/wvemin,wvemax,dyn,specmin,specmax,cmin,cmax,npspec
	common/fnames/starname,wavecut,plotname,plotname1
        common/observations/wve,flx,ysel,zsel,xspec,yspec,zspec,xsel,
     c                      nfl,nsel,nspec,dist

	common /global/ irsscale,irserrscale,exmin,exmax, nexl
        common/special/splam,spmag,sperrmag,nspc

	pi= 3.1415927d0

	write(*,*) 'plotsed', nsel
c     OLD OLD OLD
c     parameters that drive appearance of the plot
c     Plot SED between these wavelengths (mircron)
c	wvemin= 0.2
c	wvemax= 3200.

c     Dynamic range in y for SED
c	dyn= 7.5

c     details of spectral plots. Number and wavelength range.
c        npspec= 1

c        specmin(1)=  5.
c        specmin(1)=  7.5

c        specmax(1)= 40.
c        specmax(1)= 23.

c        specmin(2)=  2.4
c        specmax(2)=  5.

c     scale observed spectra to model, based on average flux in this wavelengtgh region
c        cmin= 8.5
c        cmax= 9.0
c        cmin= 6.4
c        cmax= 6.5

         CALL Clean(starname, path, lpath)
         CALL ATTACH(path,lpath,'_sed.ps/vcps',name)

         call pgbegin(0, name ,1,1)
         call pgscf(2)
         call pgsch(0.75)

c     SED 
        call pgvsize(1.09,5.0,7.7,9.5)

        xmax= -9999.
        xmin=  9999.
c        ymin=  9999.
        ymax= -9999.

c     plot model
        nplt= 0
	sumn= 0.d0
	sumf= 0.d0
        do k= 1,nfl
           if (wve(k) .gt. wvemin .and. wve(k) .lt. wvemax) then

              nplt= nplt+1
              xpl(nplt)= log10(wve(k))
              ypl(nplt)= log10(flx(k)*wve(k) )
              if (xpl(nplt) .lt. xmin) xmin= xpl(nplt)
              if (xpl(nplt) .gt. xmax) xmax= xpl(nplt)
c              if (ypl(nplt) .lt. ymin) ymin= ypl(nplt)
              if (ypl(nplt) .gt. ymax) ymax= ypl(nplt)
           endif
           if (wve(k) .gt. cmin .and. wve(k) .lt. cmax) then
              sumn= sumn+ 1
              sumf= sumf+ flx(k)*wve(k)
           endif
        enddo
        avemodel= sumf/sumn


c     plot observed spectrum
c     order by wavelength first to give smooth plots
        call indexx(nspec, xspec, idx)

  	 sumn= 0.
	 sumf= 0.
	 nsp=0
         do i= 1,nspec
	    j= idx(i)
c	    j= i

	    if (yspec(j) .gt. 0.d0) then
	       nsp=nsp+1
	       xpl1(nsp)= log10(xspec(j))
	       ypl1(nsp)= log10(yspec(j) *xspec(j)/1.d5)
	       write(80,*)'spec ordered ',i,nspec, xpl1(nsp), 
     c                              ypl1(nsp), 10**xpl1(nsp)
	       if (ypl1(nsp) .gt. ymax) ymax= ypl1(nsp)
c       write(*,*) 'plot', xspec(i), yspec(i), xpl(i), ypl(i)
	       if (xspec(j) .gt. cmin .and. xspec(j) .lt. cmax) then
		  sumn= sumn+ 1
		  sumf= sumf+ yspec(j) *xspec(j)/1.e5
	       endif
	    endif
         enddo
	if (sumn .eq. 0 .and. nspec .ne. 0) then
	   write(*,*) "check cmin-cmax and range of the spectra!"
	   STOP
	endif

c     observed photometry  (MG 16.09.10 to check maximum only)
         do i= 1,nsel
            call getphot( xsel(i), ysel(i), zsel(i), wl, ff, er )
	    if (log10(ff) .gt. ymax) ymax= log10(ff)

c       MG 19.09.14 store data, in W/m2/mu
	    zpl2(i)= wl
	    ypl2(i)= ff/wl
	 enddo

         write(*,*) 'min-max', xmin, xmax, ymax-dyn, ymax+0.5
         call pgwindow(xmin, xmax, ymax-dyn, ymax+0.5)
         call pgbox('bcnst',0.0,0,'bcnst',0.0,0)

c       MG 19.09.14
c       SORT in wavelength
        call indexx(nsel, zpl2, idx1)
	do i= 1,nsel
	   vpl(i+1)= zpl2 (idx1(I) )
	   wpl(i+1)= ypl2 (idx1(I) )
	   WRITE(*,*) i+1, vpl(i+1),  wpl(i+1)
	enddo

c       extrapolate to l=0 micron, keeping flux
c	 vpl(1)= 0.0
c	 wpl(1)= wpl(2)
	 vpl(1)= max( 0.1*vpl(2), 0.01)
	 isel= 2
 299	 isel= isel+1
  	 if (vpl(isel) .eq. vpl(2)) goto 299 
	 xt= log( wpl(2)/wpl(isel)) / log( vpl(2)/vpl(isel) ) 
	 if (xt .lt. 0.) xt= 0.
	 if (xt .eq. 0.) isel=2
	 wpl(1)= wpl(isel)* ( vpl(1)/ vpl(isel))**xt
	 write(*,*) vpl(1), vpl(isel), wpl(1), wpl(isel)
	 write(*,*) isel,  xt
	 xx(1)= log10(vpl(1))
	 xx(2)= log10(vpl(isel))
	 yy(1)= log10(wpl(1)*vpl(1))
	 yy(2)= log10(wpl(isel)*vpl(isel))
         call PGSLS (4)
c         call pgline(2, xx, yy)
	 write(*,*) 'xx,yy', xx,yy

c       extrapolate to a very long flux
	 vpl(nsel+2)= max( 10.*vpl(nsel+1), 5000.)
	 isel= nsel+1
 199	 isel= isel-1
  	 if (vpl(isel) .eq. vpl(nsel+1)) goto 199 
	 xt= log( wpl(nsel+1)/wpl(isel)) / log( vpl(nsel+1)/vpl(isel) ) 
	 if (xt .gt. 0.) goto 199
	 wpl(nsel+2)= wpl(nsel+1)* ( vpl(nsel+2)/ vpl(nsel+1))**xt

	 write(*,*)  vpl(isel), vpl(nsel+1), vpl(nsel+2), isel 
	 write(*,*)  wpl(isel), wpl(nsel+1), wpl(nsel+2), xt
	 xx(1)= log10(vpl(isel))
	 xx(2)= log10(vpl(nsel+2))
	 yy(1)= log10(wpl(isel)*vpl(isel))
	 yy(2)= log10(wpl(nsel+2)*vpl(nsel+2))
c        call pgline(2, xx, yy)
	 write(*,*) 'xx,yy', xx,yy
         call PGSLS (1)

c       Trapezium rule for all, except last point
	 sum=0.
	 do i= 1, nsel
	    sum= sum+ 0.5*(wpl(i)+wpl(i+1))*(vpl(i+1)-vpl(i))
	    write(*,*) vpl(i), wpl(i), sum
	 enddo
c       add INT_l1^l2 (F0 (l/l0)^x dl = F0 / l0^x / (1+x) *(l2^(1+x) - l1^(1+x))
	 sum= sum+   wpl(nsel+1)/ vpl(nsel+1)**xt / (1. + xt) *
     c              (vpl(nsel+2)**(1.+xt) -  vpl(nsel+1)**(1.+xt))

	 write(*,*) vpl(nsel+2), wpl(nsel+2), sum
	 Lum= sum* (4.* pi * (dist * 3.0921d19)**2) / 3.826d26 
	 write(*,*) sum, pi, dist, lum


         call pgline(nplt, xpl, ypl)

         call pglabel('log \gl [\gmm]', 
     c      'log \gl F\d\gl\u [W m\u-2\d]', ' ')


         call pgslw(2)
         call pgline(nsp, xpl1, ypl1)
         call pgslw(1)
         aveobs= sumf/sumn
c	 write(*,*) sumf, sumn


c         write( cwave ,'(f6.1)') waveint(i)
c         call pgtext( xmin+0.5*(xmax-xmin), ymax+1.0 , starname)
c       CHANGE  object_name
         call pgtext( xmin+0.72*(xmax-xmin), ymax-0.6 , starname)
c        T2CEP name
c         call pgtext( xmin+0.54*(xmax-xmin), ymax-0.6 , starname)
c        T2CEP modelatmos
c	 call pgtext( xmin+0.14*(xmax-xmin), ymax-6.5 , plotname)
	 write(*,*) xmin+0.01*(xmax-xmin), ymax-6.5 , plotname

c     plot observed photometry
         do i= 1,nsel
c	    write(*,*) i,xsel(i)
            call getphot( xsel(i), ysel(i), zsel(i), wl, ff, er )

	    isym= 4
	    if (wl .lt. wavecut) isym= 5
            call pgpnts(1, log10(wl), log10(ff), isym, 1)
            call pgerrb(6, 1, log10(wl), log10(ff), 
     c                                   log10(ff+er)-log10(ff), 0.0)
            write(80,*) 'phot ', i,xsel(i),ysel(i),zsel(i),wl,ff,er
         enddo


c     plot one or more spectra
        do i= 1, npspec

        if (i .eq. 1) then
	 vsminx=1.09
	 vsmaxx=5.0
	 vsminy=5.4
	 vsmaxy=7.2
        endif
        if (i .eq. 2) then
	 vsminx=1.09
	 vsmaxx=5.0
	 vsminy=3.1
	 vsmaxy=4.9
        endif
        if (i .eq. 3) then
	 vsminx=1.09
	 vsmaxx=5.0
	 vsminy=0.8
	 vsmaxy=2.6
        endif
	if (i .eq. 4) then
	   write(*,*) 'oeps, 3 spectra are not implemented yet'
	   stop
	endif

        call pgvsize(vsminx,vsmaxx,vsminy,vsmaxy)

c     model
        nplt= 0
        ymin=  9999.
        ymax= -9999.
        do k= 1,nfl
           if (wve(k) .gt. specmin(i)-0.1
     c                 .and. wve(k) .lt. specmax(i)+0.3) then
              nplt= nplt+1
              xpl(nplt)= wve(k)
              ypl(nplt)= flx(k)*wve(k)   /1.e-12
              if (ypl(nplt) .lt. ymin) ymin= ypl(nplt)
              if (ypl(nplt) .gt. ymax) ymax= ypl(nplt)
           endif
        enddo


c     plot observed spectrum scaled to the model
         do j= 1,nspec
	    k= idx(j)
c	    k= j

            xpl1(j)= xspec(k)
            ypl1(j)= yspec(k) *xspec(k)/1.e5  /aveobs*avemodel /1.e-12
            if (ypl1(j) .gt. ymax .and. xpl1(j) .le. specmax(i) .and.
     c          xpl1(j) .gt. specmin(i))        ymax= ypl1(j)
            if (ypl1(j) .lt. ymin .and. xpl1(j) .le. specmax(i) .and.
     c          xpl1(j) .gt. specmin(i))        ymin= ypl1(j)
         enddo

         call pgwindow(specmin(i), specmax(i), ymin*0.9, ymax*1.05)
         call pgbox('bcnst',0.0,0,'bcnst',0.0,0)

c        dashed
c	 call pgsls(2)
	 call pgsls(1)
c       blue
	 call pgsci(4)
         call pgline(nplt, xpl, ypl)
	 call pgsci(1)
	 call pgsls(1)
         call pgline(nspec, xpl1, ypl1)
         call pgslw(1)

         call pglabel(' \gl [\gmm]', 
     c      '\gl F\d\gl\u [10\u-12\d W m\u-2\d]', ' ')

	 call pgsls(1)
	do j= 1,nexl
	   xx(1)= exmin(j)
	   yy(1)= ( ymax*1.05 - ymin*0.9 )*0.05+ ymin*0.9
	   xx(2)= exmax(j)
	   yy(2)= yy(1)
	   write(*,*) j, xx,yy
	   call pgline(2,xx,yy)
	enddo

	if (i.eq.1) then
           xt= specmin(i) + 0.25*(specmax(i)-specmin(i))
c           xt= specmin(i) + 0.2*(specmax(i)-specmin(i))
c           xt= specmin(i) + 0.18*(specmax(i)-specmin(i))
           xt1= specmin(i) - 0.10*(specmax(i)-specmin(i))
c       CHANGE: name atmosphere model
	   call pgtext( xt,  ymax*0.92 , plotname)
c       CHANGE: name dust
	   call pgtext( xt1, ymax*1.15 , plotname1)
	endif

c     end plot spectra
        enddo

         call pgend

         write(*,*) 'obs model ', aveobs, avemodel
	 write(*,*) 'Luminosity', Lum

         return
         end
*23456789012345678901234567890123456789012345678901234567890123456789012

	subroutine readphot(x,mago,errmag,nobs)

c       read in observed data, and link to predicted ones.
        implicit double precision(a-h,o-z)

	parameter(no=189)
	double precision mag(no), mago(no), errmag(no), l0
        double precision splam(no),spmag(no),sperrmag(no)
	character*6 philnameo(no), nameo, name, cdum
        character fmt*6
	integer x(no)

	character*80 name1,starname,path
	character*60 plotname, plotname1

	common/fnames/starname,wavecut,plotname,plotname1
        common/special/splam,spmag,sperrmag,nspc

c       observed data
c       file name that needs to exist is called   sed_<starname>.dat
        CALL Clean(starname, path, lpath)                                      
        CALL ATTACH(path,lpath,'.dat',name1)
        CALL Clean(name1, path, lpath)                                          
        CALL ATTACHfront(path,lpath,'sed2_',name1)

	open(23, file= name1)
        write(*,*) 'readphot ',  name1, path
	
c 5	format(a6,1x, f6.3,1x, f5.3)
 5	format(a6,1x, f11.3,1x, f10.3)

        j=0
 100    j=j+1
        read(23, 5 ,err=101,end=101) philnameo(j), mago(j), errmag(j)

        cdum= philnameo(j)
        if ( (cdum(1:1).eq.'1').or.(cdum(1:1).eq.'2').or.
     c       (cdum(1:1).eq.'3').or.(cdum(1:1).eq.'4').or.
     c       (cdum(1:1).eq.'5').or.(cdum(1:1).eq.'6').or.
     c       (cdum(1:1).eq.'7').or.(cdum(1:1).eq.'8').or.
     c       (cdum(1:1).eq.'9').or.(cdum(1:1).eq.'0') ) then

        if ( (cdum(2:2).eq.'1').or.(cdum(2:2).eq.'2').or.
     c       (cdum(2:2).eq.'3').or.(cdum(2:2).eq.'4').or.
     c       (cdum(2:2).eq.'5').or.(cdum(2:2).eq.'6').or.
     c       (cdum(2:2).eq.'7').or.(cdum(2:2).eq.'8').or.
     c       (cdum(2:2).eq.'9').or.(cdum(2:2).eq.'0').or.
     c       (cdum(2:2).eq.'.') ) then

           nspc= nspc+1
           do i= 2,6
              if (cdum(i:i) .eq. '.') k= i
           enddo
           if (k.eq.6) fmt='(f6.0)'
           if (k.eq.5) fmt='(f6.1)'
           if (k.eq.4) fmt='(f6.2)'
           if (k.eq.3) fmt='(f6.3)'
           if (k.eq.2) fmt='(f6.4)'
           read( cdum, fmt) splam(nspc)
           dum= mago(j)+errmag(j)
           spmag(nspc)= log10(mago(j))
           sperrmag(nspc)= log10(dum)-spmag(nspc)
           x(j)= 1000+nspc
           mago(j)= spmag(nspc)
           errmag(j)= sperrmag(nspc)
        endif
        endif

	if (philnameo(j) .eq. '  BesU') x(j)=1
	if (philnameo(j) .eq. '  BesB') x(j)=2
	if (philnameo(j) .eq. '  BesV') x(j)=3
	if (philnameo(j) .eq. '  BesR') x(j)=4
	if (philnameo(j) .eq. '  BesI') x(j)=5

	if (philnameo(j) .eq. 'wfcamZ') x(j)=6
	if (philnameo(j) .eq. 'wfcamY') x(j)=7
	if (philnameo(j) .eq. 'wfcamJ') x(j)=8
	if (philnameo(j) .eq. 'wfcamH') x(j)=9
	if (philnameo(j) .eq. 'wfcamK') x(j)=10

	if (philnameo(j) .eq. 'denisI') x(j)=11
	if (philnameo(j) .eq. 'denisJ') x(j)=12
	if (philnameo(j) .eq. 'denisK') x(j)=13

	if (philnameo(j) .eq. '2massJ') x(j)=14
	if (philnameo(j) .eq. '2massH') x(j)=15
	if (philnameo(j) .eq. '2massK') x(j)=16

	if (philnameo(j) .eq. 'irac36') x(j)=17
	if (philnameo(j) .eq. 'irac45') x(j)=18
	if (philnameo(j) .eq. 'irac58') x(j)=19
	if (philnameo(j) .eq. 'irac80') x(j)=20

	if (philnameo(j) .eq. 'iras12') x(j)=21
	if (philnameo(j) .eq. 'iras25') x(j)=22
	if (philnameo(j) .eq. 'iras60') x(j)=23
	if (philnameo(j) .eq. 'ira100') x(j)=24

	if (philnameo(j) .eq. ' irsfJ') x(j)=25
	if (philnameo(j) .eq. ' irsfH') x(j)=26
	if (philnameo(j) .eq. ' irsfK') x(j)=27

	if (philnameo(j) .eq. '  MSXA') x(j)=28

	if (philnameo(j) .eq. 'caspiJ') x(j)=29
	if (philnameo(j) .eq. 'caspiH') x(j)=30
	if (philnameo(j) .eq. 'caspiK') x(j)=31
	if (philnameo(j) .eq. 'caspiL') x(j)=32

	if (philnameo(j) .eq. 'mips24') x(j)=33
	if (philnameo(j) .eq. 'mips70') x(j)=34
	if (philnameo(j) .eq. 'mip160') x(j)=35

	if (philnameo(j) .eq. ' ogleU') x(j)=36
	if (philnameo(j) .eq. ' ogleB') x(j)=37
	if (philnameo(j) .eq. ' ogleV') x(j)=38
	if (philnameo(j) .eq. ' ogleI') x(j)=39

	if (philnameo(j) .eq. ' casw1') x(j)=40
	if (philnameo(j) .eq. ' calw1') x(j)=41
	if (philnameo(j) .eq. ' calw2') x(j)=42
	if (philnameo(j) .eq. ' calw7') x(j)=43
	if (philnameo(j) .eq. 'calw10') x(j)=44

	if (philnameo(j) .eq. ' saaoJ') x(j)=45
	if (philnameo(j) .eq. ' saaoH') x(j)=46
	if (philnameo(j) .eq. ' saaoK') x(j)=47
	if (philnameo(j) .eq. ' saaoL') x(j)=48

c     I adopted the convention to work in log10(Flux in mJy) for submm/mm wavelenghts
c       (and not in magnitudes; the log is to get a number of same order as magnitudes)
	if (philnameo(j) .eq. 'apx450') then
           x(j)=49
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif  
	if (philnameo(j) .eq. 'apx870') then
           x(j)=50
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'ap1200') then
           x(j)=51
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif

	if (philnameo(j) .eq. 'sloanu') x(j)=52
	if (philnameo(j) .eq. 'sloang') x(j)=53
	if (philnameo(j) .eq. 'sloanr') x(j)=54
	if (philnameo(j) .eq. 'sloani') x(j)=55
	if (philnameo(j) .eq. 'sloanz') x(j)=56

	if (philnameo(j) .eq. '  esoJ') x(j)=57
	if (philnameo(j) .eq. '  esoH') x(j)=58
	if (philnameo(j) .eq. '  esoK') x(j)=59
	if (philnameo(j) .eq. '  esoL') x(j)=60
	if (philnameo(j) .eq. '  esoM') x(j)=61


	if (philnameo(j) .eq. 'ukt350') then
           x(j)=62
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'ukt450') then
           x(j)=63
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'ukt600') then
           x(j)=64
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'ukt800') then
           x(j)=65
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'ukt850') then
           x(j)=66
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'uk1100') then
           x(j)=67
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'uk1300') then
           x(j)=68
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'uk2000') then
           x(j)=69
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif

	if (philnameo(j) .eq. 'se1300') then
           x(j)=70
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif

	if (philnameo(j) .eq. '  esoN') x(j)=71
	if (philnameo(j) .eq. ' esoN1') x(j)=72
	if (philnameo(j) .eq. ' esoN2') x(j)=73
	if (philnameo(j) .eq. ' esoN3') x(j)=74
	if (philnameo(j) .eq. ' esoQ0') x(j)=75


	if (philnameo(j) .eq. ' pacsb') then
           x(j)=76
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. ' pacsg') then
           x(j)=77
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. ' pacsr') then
           x(j)=78
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'spire1') then
           x(j)=79
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'spire2') then
           x(j)=80
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'spire3') then
           x(j)=81
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif

	if (philnameo(j) .eq. 'AkarN2') x(j)=82
	if (philnameo(j) .eq. 'AkarN3') x(j)=83
	if (philnameo(j) .eq. 'AkarN4') x(j)=84
	if (philnameo(j) .eq. 'AkarS7') x(j)=85
	if (philnameo(j) .eq. 'AkaS9W') x(j)=86
	if (philnameo(j) .eq. 'AkaS11') x(j)=87
	if (philnameo(j) .eq. 'AkaL15') x(j)=88
	if (philnameo(j) .eq. 'AkL18W') x(j)=89
	if (philnameo(j) .eq. 'AkaL24') x(j)=90
	if (philnameo(j) .eq. 'AkaN60') x(j)=91
	if (philnameo(j) .eq. 'AkarWS') x(j)=92
	if (philnameo(j) .eq. 'AkarWL') x(j)=93
	if (philnameo(j) .eq. 'AkN160') x(j)=94

	if (philnameo(j) .eq. 'vistaZ') x(j)=95
	if (philnameo(j) .eq. 'vistaY') x(j)=96
	if (philnameo(j) .eq. 'vistaJ') x(j)=97
	if (philnameo(j) .eq. 'vistaH') x(j)=98
	if (philnameo(j) .eq. 'vistaK') x(j)=99

	if (philnameo(j) .eq. 'WISE1 ') x(j)=100
	if (philnameo(j) .eq. 'WISE2 ') x(j)=101
	if (philnameo(j) .eq. 'WISE3 ') x(j)=102
	if (philnameo(j) .eq. 'WISE4 ') x(j)=103

	if (philnameo(j) .eq. 'Opg   ') x(j)=104
	if (philnameo(j) .eq. 'Epg   ') x(j)=105
	if (philnameo(j) .eq. 'V495  ') x(j)=106
	if (philnameo(j) .eq. 'JpgBJ ') x(j)=107
	if (philnameo(j) .eq. 'FpgRF ') x(j)=108
	if (philnameo(j) .eq. 'NmagIN') x(j)=109

	if (philnameo(j) .eq. 'PAH1VI') x(j)=110
	if (philnameo(j) .eq. 'PAH2VI') x(j)=111
	if (philnameo(j) .eq. 'SICVI ') x(j)=112

	if (philnameo(j) .eq. 'COBE1 ') then
           x(j)=163
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'COBE2 ') then
           x(j)=164
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'COBE3 ') then
           x(j)=113
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'COBE4 ')  then
           x(j)=114
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif
	if (philnameo(j) .eq. 'COBE5 ')  then
           x(j)=115
           dum= mago(j)+errmag(j)
           mago(j)= log10(mago(j))
           errmag(j)= log10(dum)-mago(j)
        endif

	if (philnameo(j) .eq. 'Hippac') x(j)=116
	if (philnameo(j) .eq. 'TychoB') x(j)=117
	if (philnameo(j) .eq. 'TychoV') x(j)=118


	if (philnameo(j) .eq. 'CNFK  ') x(j)=119
	if (philnameo(j) .eq. 'CNESO ') x(j)=120
	if (philnameo(j) .eq. 'TiOFK ') x(j)=121
	if (philnameo(j) .eq. 'TiOESO') x(j)=122
	if (philnameo(j) .eq. 'Halpha') x(j)=123

	if (philnameo(j) .eq. 'GALFUV') x(j)=124
	if (philnameo(j) .eq. 'GALNUV') x(j)=125

	if (philnameo(j) .eq. 'MACHOB') x(j)=126
	if (philnameo(j) .eq. 'MACHOR') x(j)=127

	if (philnameo(j) .eq. 'EROSB ') x(j)=128
	if (philnameo(j) .eq. 'EROSR ') x(j)=129

	if (philnameo(j) .eq. 'CousR ') x(j)=130
	if (philnameo(j) .eq. 'CousI ') x(j)=131

	if (philnameo(j) .eq. 'F070W ') x(j)=132
	if (philnameo(j) .eq. 'F090W ') x(j)=133
	if (philnameo(j) .eq. 'F115W ') x(j)=134
	if (philnameo(j) .eq. 'F150W ') x(j)=135
	if (philnameo(j) .eq. 'F200W ') x(j)=136
	if (philnameo(j) .eq. 'F277W ') x(j)=137
	if (philnameo(j) .eq. 'F356W ') x(j)=138
	if (philnameo(j) .eq. 'F444W ') x(j)=139
	if (philnameo(j) .eq. 'F560W ') x(j)=140
	if (philnameo(j) .eq. 'F770W ') x(j)=141
	if (philnameo(j) .eq. 'F1000W') x(j)=142
	if (philnameo(j) .eq. 'F1130W') x(j)=143
	if (philnameo(j) .eq. 'F1280W') x(j)=144
	if (philnameo(j) .eq. 'F1500W') x(j)=145
	if (philnameo(j) .eq. 'F1800W') x(j)=146
	if (philnameo(j) .eq. 'F2100W') x(j)=147
	if (philnameo(j) .eq. 'F2550W') x(j)=148

	if (philnameo(j) .eq. 'F140M ') x(j)=149
	if (philnameo(j) .eq. 'F158M ') x(j)=150
	if (philnameo(j) .eq. 'F162M ') x(j)=151
	if (philnameo(j) .eq. 'F182M ') x(j)=152
	if (philnameo(j) .eq. 'F210M ') x(j)=153
	if (philnameo(j) .eq. 'F250M ') x(j)=154
	if (philnameo(j) .eq. 'F300M ') x(j)=155
	if (philnameo(j) .eq. 'F335M ') x(j)=156
	if (philnameo(j) .eq. 'F360M ') x(j)=157
	if (philnameo(j) .eq. 'F380M ') x(j)=158
	if (philnameo(j) .eq. 'F410M ') x(j)=159
	if (philnameo(j) .eq. 'F430M ') x(j)=160
	if (philnameo(j) .eq. 'F460M ') x(j)=161
	if (philnameo(j) .eq. 'F480M ') x(j)=162

	if (philnameo(j) .eq. 'AF475W') x(j)=165
	if (philnameo(j) .eq. 'AF555W') x(j)=166
	if (philnameo(j) .eq. 'AF814W') x(j)=167
	if (philnameo(j) .eq. 'AF110W') x(j)=168
	if (philnameo(j) .eq. 'AF160W') x(j)=169
	if (philnameo(j) .eq. 'AF127M') x(j)=170
	if (philnameo(j) .eq. 'AF139M') x(j)=171
	if (philnameo(j) .eq. 'AF153M') x(j)=172

	if (philnameo(j) .eq. 'GAIAG ') x(j)=173
	if (philnameo(j) .eq. 'GAIABp') x(j)=174
	if (philnameo(j) .eq. 'GAIARp') x(j)=175
	if (philnameo(j) .eq. 'GAIRVS') x(j)=176

c     some futching to account for variability (based on CWLEO)
c        call getphot( x(j), mag, emag, l0, flux, eflux )
c        scerr= -17.* alog10(l0) +25.821
c        if (scerr .lt. 1.) scerr= 1.0
c        errmag(j)= errmag(j)* scerr

	if (philnameo(j) .eq. '!') goto 101
	if (philnameo(j) .eq. '#') goto 101
	goto 100
 101	continue
	nobs= j-1

	if (nobs .gt. no) then
           write(*,*) 'INCREASE no'
           STOP
        endif

	close(23)

	return
	end
*23456789012345678901234567890123456789012345678901234567890123456789012

	subroutine readspec(x,mago,errmag,nob)

c       read in observed spectral data
        implicit double precision(a-h,o-z)

	parameter(ns= 1900)
	double precision mag(ns), mago(ns), errmag(ns)
	double precision x(ns), xlow(ns), xup(ns)
	double precision dumx(ns), dumy(ns), dumz(ns), ord(ns)
	integer in

	data xlow /ns*0.0/
	data xup  /ns*9999./

	character*80 starname,specname,path,name,cdum
	character*60 plotname, plotname1

	common/fnames/starname,wavecut,plotname,plotname1

c       observed data
c       file name that needs to exist is called   spec_<starname>.dat
        CALL Clean(starname, path, lpath)                                    
        CALL ATTACH(path,lpath,'.dat',name)
        CALL Clean(name, path, lpath)                                          
        CALL ATTACHfront(path,lpath,'spec_',name)

        write(*,'(A)') 'readspec ',  name, path

	nob= 0
	write(80,*) 'readspec'

c       observed data
	open(23, file= name)

c       number of spectra
	read(23,*) nns
	write(80,*) nns

	do I= 1,NNS

c       filename
	read(23,'(a80)') specname
	write(80,*) '|',specname,'|'

c	read CODE, scaling flux, scaling errorbar
c       CODE gives option to have different input formats, hardcoded later
	read(23,*) IC, sf, se

c       read number of excluded segments
	read(23,*) nex
	write(80,*) IC, sf, se, nex
c       read lower and upper wavelength interval, in units of inputfile
	do  J= 1,NEX
	   read(23,*) xlow(j), xup(j)
	   write(80,*) j,xlow(j), xup(j)
	enddo

	open(33, FILE= specname)

	if (IC .eq. 1) then
c       IRS spectra
c       format: wave(mu), flux(Jy), errflux(Jy), order
	k=1
 111	read(33,*, err=112,end=112) dumx(k), dumy(k), dumz(k),ord(k)
	write(80,*) k,dumx(k), dumy(k), dumz(k), ord(k)

	k=k+1
	goto 111
 112	continue
	np= k-1

c       check if point is in excluded wavelength region
	do k= 1,np
	   in= 1
	   do j= 1,nex
c	      if((dumx(k) .gt. xlow(j)).and.(dumx(k) .lt. xup(j))) in=0
	   enddo

c       MG 20.08.08 require positive flux, and non-zero errorbar as well
c       MG 20.07.09 For plotting take all
	   if ((in .ge. -1) .and. (1. .gt. 0.0) 
     c                      .and. (1. .gt. 0.0)) then
c       OK, convert (if needed) wavelength to micron, and flux(error) to W/m2/mu,
c           scale flux and errors according to inputfile, and add this point.
	      nob= nob+1
	      x(nob)= dumx(k)
	      mago(nob)= dumy(k)     *2.99792458e-12/dumx(k)/dumx(k)
              dum= (dumy(k)+dumz(k)) *2.99792458e-12/dumx(k)/dumx(k)
              errmag(nob)= dum-mago(nob)
c       MG 20.08.08 scale flux and error with 1.e5 to avoid underflows
	      mago(nob)= mago(nob)     *sf *1.0e5
	      errmag(nob)= errmag(nob) *se *1.0e5
	   endif
	enddo

c       end IRS spectra
	endif

	if (IC .eq. 2) then
c       SWS LWS spectra; assume 5% errorbar
c       format: wave(mu), flux(Jy)
	k=1
 211	read(33,*, err=212,end=212) dumx(k), dumy(k), dumz(k)
        if (dumz(k) .eq. 0.) dumz(k)= 0.05* dumy(k)
	write(80,*) IC, k,dumx(k), dumy(k), dumz(k)

	k=k+1
	goto 211
 212	continue
	np= k-1

c       check if point is in excluded wavelength region
	do k= 1,np
	   in= 1
	   do j= 1,nex
c	      if((dumx(k) .gt. xlow(j)).and.(dumx(k) .lt. xup(j))) in=0
	   enddo

	   if ((in .eq. 1) .and. (1.0 .gt. 0.0))  then
c	   if ((in .ge. -1) .and. (1.0 .gt. 0.0))  then
c       OK, convert (if needed) wavelength to micron, and flux(error) to W/m2/mu,
c           scale flux and errors according to inputfile, and add this point.
	      nob= nob+1
	      x(nob)= dumx(k)
	      mago(nob)= dumy(k)     *2.99792458e-12/dumx(k)/dumx(k)
              dum= (dumy(k)+dumz(k)) *2.99792458e-12/dumx(k)/dumx(k)
              errmag(nob)= dum-mago(nob)
c       MG 20.08.08 scale flux and error with 1.e5 to avoid underflows
	      mago(nob)= mago(nob)     *sf *1.0e5
	      errmag(nob)= errmag(nob) *se *1.0e5
	   endif
	enddo

c       end SWS LWS spectra
	endif

	if (IC .eq. 3) then
c       IRAS LRS spectra, as from Calgary database; assume 5% errorbar
c       format: wave(mu), flux W/m2/mu   NEW FORMAT website: W/m2
c       first part spectrum
	read(33,*) cdum
	k=1
 311	read(33,*, err=312,end=312) dumx(k), dumy(k)
        dumy(k)= dumy(k)/  dumx(k)
	write(80,*) IC, k,dumx(k), dumy(k)

	k=k+1
	goto 311
 312	continue
c       second part spectrum
 313	read(33,*, err=314,end=314) dumx(k), dumy(k)
        dumy(k)= dumy(k)/  dumx(k)
	write(80,*) IC, k,dumx(k), dumy(k)

	k=k+1
	goto 313
 314	continue
	np= k-1

c       check if point is in excluded wavelength region
	do k= 1,np
	   in= 1
	   do j= 1,nex
c	      if((dumx(k) .gt. xlow(j)).and.(dumx(k) .lt. xup(j))) in=0
	   enddo

c	   if ((in .ge. -1) .and. (1.0 .gt. 0.0))  then
	   if ((in .eq. 1) .and. (1.0 .gt. 0.0))  then
c       OK, convert (if needed) wavelength to micron, and flux(error) to W/m2/mu,
c           scale flux and errors according to inputfile, and add this point.
	      nob= nob+1
	      x(nob)= dumx(k)
	      mago(nob)= dumy(k)
              dum= (dumy(k)+0.05*dumy(k))
              errmag(nob)= dum-mago(nob)
c       MG 20.08.08 scale flux and error with 1.e5 to avoid underflows
	      mago(nob)= mago(nob)     *sf *1.0e5
	      errmag(nob)= errmag(nob) *se *1.0e5
	   endif
	enddo

c       end IRAS LRS spectra
	endif


	close(33)
	if (nob .gt. ns) then
           write(*,*) 'INCREASE ns'
           STOP
        endif

c       end loop spectra
	ENDDO

	do i=1,nob
	   write(80,*) 'spec ', i, x(i), mago(i), errmag(i)
	enddo

	close(23)

	return
	end
*23456789012345678901234567890123456789012345678901234567890123456789012

      SUBROUTINE indexx(n,arr,indx)

      INTEGER n,indx(n),M,NSTACK
      DOUBLE PRECISION arr(n)
      PARAMETER (M=7,NSTACK=50)
      INTEGER i,indxt,ir,itemp,j,jstack,k,l,istack(NSTACK)
      DOUBLE PRECISION a
      do 11 j=1,n
        indx(j)=j
11    continue
      jstack=0
      l=1
      ir=n
1     if(ir-l.lt.M)then
        do 13 j=l+1,ir
          indxt=indx(j)
          a=arr(indxt)
          do 12 i=j-1,1,-1
            if(arr(indx(i)).le.a)goto 2
            indx(i+1)=indx(i)
12        continue
          i=0
2         indx(i+1)=indxt
13      continue
        if(jstack.eq.0)return
        ir=istack(jstack)
        l=istack(jstack-1)
        jstack=jstack-2
      else
        k=(l+ir)/2
        itemp=indx(k)
        indx(k)=indx(l+1)
        indx(l+1)=itemp
        if(arr(indx(l+1)).gt.arr(indx(ir)))then
          itemp=indx(l+1)
          indx(l+1)=indx(ir)
          indx(ir)=itemp
        endif
        if(arr(indx(l)).gt.arr(indx(ir)))then
          itemp=indx(l)
          indx(l)=indx(ir)
          indx(ir)=itemp
        endif
        if(arr(indx(l+1)).gt.arr(indx(l)))then
          itemp=indx(l+1)
          indx(l+1)=indx(l)
          indx(l)=itemp
        endif
        i=l+1
        j=ir
        indxt=indx(l)
        a=arr(indxt)
3       continue
          i=i+1
        if(arr(indx(i)).lt.a)goto 3
4       continue
          j=j-1
        if(arr(indx(j)).gt.a)goto 4
        if(j.lt.i)goto 5
        itemp=indx(i)
        indx(i)=indx(j)
        indx(j)=itemp
        goto 3
5       indx(l)=indx(j)
        indx(j)=indxt
        jstack=jstack+2
        if(jstack.gt.NSTACK)pause 'NSTACK too small in indexx'
        if(ir-i+1.ge.j-l)then
          istack(jstack)=ir
          istack(jstack-1)=i
          ir=j-1
        else
          istack(jstack)=j-1
          istack(jstack-1)=l
          l=i
        endif
      endif
      goto 1
      END

*23456789012345678901234567890123456789012345678901234567890123456789012

        subroutine getphot( isel, mag, emag, l0, flux, eflux )

c     based on index of available filters, magnitude and error, return
c     the effective wavelength and flux with error.

c     available filters, effective wavelengths and zeropoints have to be in sync 
c     with PSCfoldORIG
        implicit double precision(a-h,o-z)

	parameter(no=189)

        integer isel
        double precision mag
	real flux, l0, eflux

        double precision splam(no),spmag(no),sperrmag(no)
        common/special/splam,spmag,sperrmag,nspc


        l0=    1.e9
        flux=  1.e9
        eflux= 0.

	write(*,*) 'getph ', isel, mag, emag, nspc
	if (isel .ge. 1000) then
	   j= isel-1000
	   l0= splam(j)

	   dum= 2.9979e-15/l0/l0* 10**mag 
	   flux= dum
	   dum= 2.9979e-15/l0/l0* 10**(mag+emag)
	   eflux= dum - flux

	endif

c     1-5 Bessell UBVRI
        if (isel .eq. 1) then
           l0= 0.366
           zp= 4.213e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 2) then
           l0= 0.438
           zp= 6.255e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 3) then
           l0= 0.545
           zp= 3.627e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 4) then
           l0= 0.641
           zp= 2.205e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 5) then
           l0= 0.798
           zp= 1.142e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     6-10 WFCAM ZYJHK
        if (isel .eq. 6) then
           l0= 0.8817
           zp= 8.807e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 7) then
           l0= 1.0305
           zp= 5.834e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 8) then
           l0= 1.2483
           zp= 3.022e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 9) then
           l0= 1.6313
           zp= 1.179e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 10) then
           l0= 2.2010
           zp= 4.018e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     11-13 DENIS IJK
        if (isel .eq. 11) then
           l0= 0.791
           zp= 11.82e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 12) then
           l0= 1.228
           zp= 3.19e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 13) then
           l0= 2.145
           zp= 4.38e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif


c     14-16 2MASS JHK
        if (isel .eq. 14) then
           l0= 1.235
           zp= 3.137e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 15) then
           l0= 1.662
           zp= 1.130e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 16) then
           l0= 2.159
           zp= 4.312e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     17-20 IRAC 36 45 58 80
        if (isel .eq. 17) then
           l0= 3.55
           zp= 6.63e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 18) then
           l0= 4.49
           zp= 2.67e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 19) then
           l0= 5.73
           zp= 10.81e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 20) then
           l0= 7.87
           zp= 3.08e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif


c     21-24 IRAS 12 25 60 100
        if (isel .eq. 21) then
           l0= 12.
           zp= 40.5 *2.998e-12/l0/l0

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

        if (isel .eq. 22) then
           l0= 25.
           zp= 8.97 *2.998e-12/l0/l0

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
         endif

        if (isel .eq. 23) then
           l0= 60.
           zp= 1.45 *2.998e-12/l0/l0

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

        if (isel .eq. 24) then
           l0= 100.
           zp= 0.423 *2.998e-12/l0/l0

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif


c     25-27 IRSF JHK
        if (isel .eq. 25) then
           l0= 1.250
           zp= 3.036e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 26) then
           l0= 1.644
           zp= 1.184e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 27) then
           l0= 2.149
           zp= 4.45e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     28    MSX A
        if (isel .eq. 28) then
           l0= 8.28
           zp= 2.364e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     29-32 CASPIR JHKL
        if (isel .eq. 29) then
           l0= 1.24
           zp= 3.182e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 30) then
           l0= 1.68
           zp= 1.101e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 31) then
           l0= 2.22
           zp= 3.993e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 32) then
           l0= 3.59
           zp= 6.306e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     33-35 MIPS 24 70 160
        if (isel .eq. 33) then
           l0= 24.0
           zp= 3.81e-14

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 34) then
           l0= 70.0
           zp= 4.84e-16

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 35) then
           l0= 160.0
           zp= 1.958e-17

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     36-39 OGLE UBVI
        if (isel .eq. 36) then
           l0= 0.372
           zp= 4.358e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 37) then
           l0= 0.431
           zp= 6.229e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 38) then
           l0= 0.536
           zp= 3.784e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 39) then
           l0= 0.820
           zp= 1.060e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif


c     40-44 ISOCAM SW1 LW1,2,7,10
        if (isel .eq. 40) then
           l0= 3.6
           zp= 6.508e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 41) then
           l0= 4.5
           zp= 2.692e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 42) then
           l0= 6.7
           zp= 6.028e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 43) then
           l0= 9.6
           zp= 1.384e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 44) then
           l0= 12.0
           zp= 7.233e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif


c     45-48 SAAO JHKL
        if (isel .eq. 45) then
           l0= 1.23
           zp= 3.255e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 46) then
           l0= 1.66
           zp= 1.145e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 47) then
           l0= 2.23
           zp= 3.892e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 48) then
           l0= 3.44
           zp= 7.499e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     49-51 'APEX' 450, 870, 1200 (scuba 450/ LABOCCA 870/ MAMBO 1200) [milliJy]
        if (isel .eq. 49) then
           l0= 450.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 50) then
           l0= 870.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 51) then
           l0= 1200.
           zp= 1.e-21

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif


c     52-56 Sloan ugriz
        if (isel .eq. 52) then
           l0= 0.3581
           zp= 40.66e-9

           dum=10**(-0.4*(mag-0.799))
           flux= zp*dum
           dum=10**(-0.4*(mag-0.799-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 53) then
           l0= 0.4686
           zp= 55.82e-9

           dum=10**(-0.4*(mag+0.129))
           flux= zp*dum
           dum=10**(-0.4*(mag+0.129-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 54) then
           l0= 0.6165
           zp= 25.52e-9

           dum=10**(-0.4*(mag-0.125))
           flux= zp*dum
           dum=10**(-0.4*(mag-0.125-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 55) then
           l0= 0.7482
           zp= 14.23e-9

           dum=10**(-0.4*(mag-0.340))
           flux= zp*dum
           dum=10**(-0.4*(mag-0.340-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 56) then
           l0= 0.8931
           zp= 8.526e-9

           dum=10**(-0.4*(mag-0.511))
           flux= zp*dum
           dum=10**(-0.4*(mag-0.511-emag))
           eflux= zp*dum - flux
        endif


c     57-61 ESO JHKLM
        if (isel .eq. 57) then
           l0= 1.228
           zp= 2.907e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 58) then
           l0= 1.651
           zp= 1.146e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 59) then
           l0= 2.216
           zp= 4.025e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 60) then
           l0= 3.771
           zp= 5.125e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 61) then
           l0= 4.772
           zp= 2.217e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     62-69 UKT14 350,450,600,800,850,1100,1300,2000 micron [milliJy]
        if (isel .eq. 62) then
           l0= 350.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 63) then
           l0= 443.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 64) then
           l0= 647.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 65) then
           l0= 790.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 66) then
           l0= 850.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 67) then
           l0= 1102.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 68) then
           l0= 1259.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 69) then
           l0= 1921.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif

c       70 SEST single-channel
        if (isel .eq. 70) then
           l0= 1300.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif

c       71-75 ESO mid-IR bolometer
        if (isel .eq. 71) then
           l0= 9.68
           zp= 1.202e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 72) then
           l0= 8.36
           zp= 2.420e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 73) then
           l0= 9.79
           zp= 1.302e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 74) then
           l0= 12.82
           zp= 4.213e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 75) then
           l0= 18.67
           zp= 1.016e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c       76-81 PACS blue, green, red; SPIRE band 1,2,3
        if (isel .eq. 76) then
           l0= 70.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 77) then
           l0= 100.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 78) then
           l0= 160.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 79) then
           l0= 250.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 80) then
           l0= 350.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 81) then
           l0= 500.
           zp= 1.e-19

           dum= 2.9979e-15/l0/l0* 10**mag 
           flux= dum
           dum= 2.9979e-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif

c       Akari  IRC (82-84) MIR-S MIR-L FIS
        if (isel .eq. 82) then
           l0= 2.4
           zp= 3.09e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 83) then
           l0= 3.2
           zp= 0.973e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 84) then
           l0= 4.1
           zp= 3.147e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 85) then
           l0= 7.0
           zp= 4.49e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 86) then
           l0= 9.0
           zp= 1.93e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 87) then
           l0= 11.0
           zp= 9.073e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 88) then
           l0= 15.0
           zp= 2.043e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 89) then
           l0= 18.0
           zp= 1.019e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 90) then
           l0= 24.0
           zp= 4.010e-14

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 91) then
           l0= 65.
           zp= 6.72e-16

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 92) then
           l0= 90.
           zp= 2.24e-16

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 93) then
           l0= 140.
           zp= 2.71e-17

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 94) then
           l0= 160.
           zp= 1.73e-17

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     95-99 VISTA ZYJHK
        if (isel .eq. 95) then
           l0= 0.876
           zp= 8.905d-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 96) then
           l0= 1.018
           zp= 6.053d-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 97) then
           l0= 1.246
           zp= 3.022d-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 98) then
           l0= 1.631
           zp= 1.164d-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 99) then
           l0= 2.133
           zp= 4.476d-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     WISE 1,2,3,4 filters
        if (isel .eq. 100) then
           l0= 3.353
           zp= 8.12e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

        if (isel .eq. 101) then
           l0= 4.603
           zp= 2.39e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

        if (isel .eq. 102) then
           l0= 11.56
           zp= 6.100e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

        if (isel .eq. 103) then
           l0= 22.09
           zp= 4.93e-14

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     Photographic magnitudes 104-109
        if (isel .eq. 104) then
           l0= 0.42
           zp= 5.69e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

        if (isel .eq. 105) then
           l0= 0.64
           zp= 2.21e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

        if (isel .eq. 106) then
           l0= 0.56
           zp= 3.33e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

        if (isel .eq. 107) then
           l0= 0.47
           zp= 5.31e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

        if (isel .eq. 108) then
           l0= 0.66
           zp= 2.08e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

        if (isel .eq. 109) then
           l0= 0.83
           zp= 1.03e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif


c     ESO VISIR 110-112
        if (isel .eq. 110) then
           l0= 8.59
           zp= 2.110e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 111) then
           l0= 11.25
           zp= 7.296e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 112) then
           l0= 11.85
           zp= 6.148e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     COBE filters 3,4,5: 113-115 ; 1,2: 163-164
        if (isel .eq. 163) then
           l0= 1.25
           zp= 1.e-19

           dum= 2.9979d-15/l0/l0* 10**mag
           flux= dum
           dum= 2.9979d-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 164) then
           l0= 2.2
           zp= 1.e-19

           dum= 2.9979d-15/l0/l0* 10**mag
           flux= dum
           dum= 2.9979d-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 113) then
           l0= 3.57
           zp= 1.e-19

           dum= 2.9979d-15/l0/l0* 10**mag
           flux= dum
           dum= 2.9979d-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 114) then
           l0= 4.93
           zp= 1.e-19

           dum= 2.9979d-15/l0/l0* 10**mag
           flux= dum
           dum= 2.9979d-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif
        if (isel .eq. 115) then
           l0= 12.71
           zp= 1.e-19

           dum= 2.9979d-15/l0/l0* 10**mag
           flux= dum
           dum= 2.9979d-15/l0/l0* 10**(mag+emag)
           eflux= dum - flux
        endif

c     116-118 Hipparcos Hp, Tycho B,V 
        if (isel .eq. 116) then
           l0= 0.5275
           zp= 3.916d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 117) then
           l0= 0.4203
           zp= 6.586d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 118) then
           l0= 0.5319
           zp= 3.949d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     119-123 CN TiO Halpha filters
        if (isel .eq. 119) then
           l0= 0.770
           zp= 1.258d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 120) then
           l0= 0.770
           zp= 1.287d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 121) then
           l0= 0.810
           zp= 1.095d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 122) then
           l0= 0.816
           zp= 1.072d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 123) then
           l0= 0.6568
           zp= 1.870d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif


c     124-125 GALEX
        if (isel .eq. 124) then
           l0= 0.155
           zp= 6.74d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 125) then
           l0= 0.235
           zp= 4.36d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     126-127 MACHO
        if (isel .eq. 126) then
           l0= 0.5225
           zp= 4.067d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 127) then
           l0= 0.6950
           zp= 1.8016d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     128-129 EROS
        if (isel .eq. 128) then
           l0= 0.54
           zp= 3.468d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 129) then
           l0= 0.74
           zp= 1.4219d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     130-131 Cousins RI
        if (isel .eq. 130) then
           l0= 0.6470
           zp= 2.137d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 131) then
           l0= 0.7865
           zp= 1.200d-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c     132-162  JWST
        if (isel .eq. 132) then
           l0= 0.70
           zp= 1.758e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 133) then
           l0= 0.90
           zp= 8.445e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 134) then
           l0= 1.15
           zp= 4.083e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 135) then
           l0= 1.50
           zp= 1.594e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 136) then
           l0= 2.00
           zp= 5.929e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 137) then
           l0= 2.77
           zp= 1.701e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 138) then
           l0= 3.56
           zp= 6.660e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 139) then
           l0= 4.44
           zp= 2.836e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 140) then
           l0= 5.60
           zp= 1.123e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 141) then
           l0= 7.70
           zp= 3.416e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 142) then
           l0= 10.0
           zp= 1.196e-12

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 143) then
           l0= 11.3
           zp= 7.193e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 144) then
           l0= 12.8
           zp= 4.430e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 145) then
           l0= 15.0
           zp= 2.318e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 146) then
           l0= 18.0
           zp= 1.145e-13

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 147) then
           l0= 21.0
           zp= 6.396e-14

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 148) then
           l0= 25.5
           zp= 2.899e-14

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 149) then
           l0= 1.40
           zp= 2.024e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 150) then
           l0= 1.58
           zp= 1.33e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 151) then
           l0= 1.62
           zp= 1.198e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 152) then
           l0= 1.82
           zp= 7.877e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 153) then
           l0= 2.10
           zp= 4.862e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 154) then
           l0= 2.50
           zp= 2.489e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 155) then
           l0= 3.00
           zp= 1.257e-10

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 156) then
           l0= 3.35
           zp= 8.183e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 157) then
           l0= 3.60
           zp= 6.151e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 158) then
           l0= 3.80
           zp= 4.894e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 159) then
           l0= 4.10
           zp= 3.838e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 160) then
           l0= 4.30
           zp= 3.187e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 161) then
           l0= 4.60
           zp= 2.373e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 162) then
           l0= 4.80
           zp= 2.005e-11

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c       163 164 COBE DIRBE, see earlier !

c     HST ACS 165-172
        if (isel .eq. 165) then
           l0= 0.475
           zp= 5.260e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 166) then
           l0= 0.540
           zp= 3.788e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 167) then
           l0= 0.814
           zp= 1.127e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 168) then
           l0= 1.10
           zp= 4.311e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 169) then
           l0= 1.53
           zp= 1.454e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 170) then
           l0= 1.273
           zp= 2.760e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 171) then
           l0= 1.383
           zp= 2.104e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 172) then
           l0= 1.532
           zp= 1.460e-9

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif

c       GAIA G Bp Rp RVS
        if (isel .eq. 173) then
           l0= 0.673
           zp= 2.182e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 174) then
           l0= 0.532
           zp= 3.891e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 175) then
           l0= 0.797
           zp= 1.218e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif
        if (isel .eq. 176) then
           l0= 0.860
           zp= 0.9088e-8

           dum=10**(-0.4*mag)
           flux= zp*dum
           dum=10**(-0.4*(mag-emag))
           eflux= zp*dum - flux
        endif



cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     convert to W/m2
        flux=  flux *l0
        eflux= eflux*l0

        return
        end

*23456789012345678901234567890123456789012345678901234567890123456789012

